@@ -6,12 +6,12 @@
 """
 __docformat__ = "restructuredtext en"
 
-from cubicweb.selectors import implements
+from cubicweb.selectors import is_instance
 from cubicweb.server.hook import Hook, match_rtype
 
 class ActivityProgressHook(Hook):
     __regid__ = 'timesheet_update_activity'
-    __select__ = Hook.__select__ & implements('Activity')
+    __select__ = Hook.__select__ & is_instance('Activity')
     events = ('after_update_entity', )
 
     def __call__(self):
