@@ -7,7 +7,7 @@ from logilab.common.date import date_range, previous_month, next_month
 from rql.utils import rqlvar_maker
 
 from cubicweb.view import AnyRsetView, EntityView
-from cubicweb.selectors import match_form_params, implements, one_line_rset
+from cubicweb.selectors import match_form_params, is_instance, one_line_rset
 from cubicweb.uilib import toggle_action
 from cubicweb.web import INTERNAL_FIELD_VALUE, stdmsgs, form
 
@@ -20,7 +20,7 @@ WORKING_HALF_DAYS = list(WORKING_AM_DAYS) + list(WORKING_PM_DAYS)
 
 class CWUserActivitySummaryView(EntityView):
     __regid__ = 'euser-stats'
-    __select__ = match_form_params('start', 'stop') & implements('CWUser')
+    __select__ = match_form_params('start', 'stop') & is_instance('CWUser')
 
     def cell_call(self, row, col):
         _ = self._cw._
@@ -61,7 +61,7 @@ class CWUserActivitySummaryView(EntityView):
 
 class CWUserActivitySubmitFormView(form.FormViewMixIn, EntityView):
     __regid__ = 'euser-activities-submitform'
-    __select__ = one_line_rset() & implements('CWUser')
+    __select__ = one_line_rset() & is_instance('CWUser')
     domid = 'activityForm'
 
     def cell_call(self, row, col, year=None, month=None, day=None, **kwargs):
@@ -98,7 +98,7 @@ class CWUserActivitySubmitFormView(form.FormViewMixIn, EntityView):
 
 class EuserMonitorCalendar(EntityView):
     __regid__ = 'user_activity_calendar'
-    __select__ = implements('CWUser',)
+    __select__ = is_instance('CWUser',)
 
     def cell_call(self, row, col, year=None, month=None, calid=None):
         self._cw.add_js('cubicweb.ajax.js')
@@ -153,12 +153,12 @@ class EuserMonitorCalendar(EntityView):
         prevdate = previous_month(curdate)
         nextdate = next_month(curdate)
         rql = 'Any X WHERE X eid %s' % user.eid
-        prevlink = self._cw.build_ajax_replace_url(calid, rql, 'user_activity_calendar',
-                                                   replacemode='swap',
-                                                   month=prevdate.month, year=prevdate.year)
-        nextlink = self._cw.build_ajax_replace_url(calid, rql, 'user_activity_calendar',
-                                                   replacemode='swap',
-                                                   month=nextdate.month, year=nextdate.year)
+        prevlink = self._cw.ajax_replace_url(calid, rql=rql, vid='user_activity_calendar',
+                                             replacemode='swap',
+                                             month=prevdate.month, year=prevdate.year)
+        nextlink = self._cw.ajax_replace_url(calid, rql=rql,vid= 'user_activity_calendar',
+                                             replacemode='swap',
+                                             month=nextdate.month, year=nextdate.year)
         return prevlink, nextlink
 
     def _build_activities(self, user, firstday, lastday):
