@@ -1,4 +1,4 @@
-from cubicweb.selectors import implements
+from cubicweb.selectors import is_instance
 from cubicweb.web.views import autoform
 from cubicweb.web import INTERNAL_FIELD_VALUE, uicfg, formfields as ff
 from cubicweb.web.formwidgets import HiddenInput
@@ -17,7 +17,7 @@ def tp_periods_choices(form, field, limit=None):
     if form._cw.form.get('vid') == 'holidays_form':
         rset = form._cw.execute("Any C WHERE R use_calendar CU, CU use_calendar C, "
                                 "R euser U, U eid %(u)s", {'u':form._cw.user.eid})
-        return sorted((v.view('combobox'), v.eid)
+        return sorted((v.view('combobox'), unicode(v.eid))
                       for v in rset.entities())
     return field.__class__.choices(field, form, limit=limit)
 _affk.tag_object_of(('*', 'periods', 'Timeperiod'),
@@ -43,14 +43,14 @@ def activity_done_by_choices(form, field, limit=None):
         if limit is not None:
             rql += 'LIMIT %s ' % limit
         rql += 'WHERE R is Resource, R title T'
-        return sorted((entity.view('combobox'), entity.eid)
+        return sorted((entity.view('combobox'), unicode(entity.eid))
                       for entity in form._cw.execute(rql).entities())
     # users can't edit an existing done_by relation
     if entity.has_eid():
         return []
     rql = 'Any R,T WHERE R euser U, R title T, U eid %(u)s'
     res = form._cw.execute(rql, {'u': user.eid}).get_entity(0, 0)
-    return [(res.view('combobox'), res.eid)]
+    return [(res.view('combobox'), unicode(res.eid))]
 _affk.tag_subject_of(('Activity', 'done_by', '*'),
                      {'choices': activity_done_by_choices})
 
@@ -70,8 +70,8 @@ def activity_done_for_choices(form, field, limit=None):
                'WO in_state S, S name "%s"' % (limit, open_state))
         rset = form._cw.execute(rql)
         if rset:
-            options += [(req._('workorders %s' % open_state), None)]
-            options += sorted((entity.view('combobox'), entity.eid)
+            options += [(req._('workorders in state %s') % req._(open_state), None)]
+            options += sorted((entity.view('combobox'), unicode(entity.eid))
                               for entity in rset.entities())
         else:
             options += [(req._('no workorders in state %s') % req._(open_state),
@@ -85,13 +85,13 @@ def activity_done_for_choices(form, field, limit=None):
                                              's': open_state})
     if rset:
         options += [(req._('your workorders'), None)]
-        options += sorted((entity.view('combobox'), entity.eid)
+        options += sorted((entity.view('combobox'), unicode(entity.eid))
                           for entity in rset.entities())
     rset = req.execute(rql+', NOT U eid %(u)s', {'u': req.user.eid,
                                                  's': open_state})
     if rset:
         options += [(req._('other workorders'), None)]
-        options += sorted((entity.view('combobox'), entity.eid)
+        options += sorted((entity.view('combobox'), unicode(entity.eid))
                           for entity in rset.entities())
     if not options:
         options += [(req._('no workorders'),
