@@ -6,7 +6,7 @@ from logilab.mtconverter import xml_escape
 from cubicweb.schema import display_name
 from cubicweb.view import EntityView
 from cubicweb.uilib import toggle_link
-from cubicweb.selectors import implements, one_line_rset
+from cubicweb.selectors import is_instance, one_line_rset
 from cubicweb.web.views import baseviews, primary, tabs
 
 from cubes.calendar.views import primaries as cal_primaries
@@ -38,7 +38,7 @@ def print_resource_ratio(self, rset):
 # order #####################################################################
 
 class OrderPrimaryView(tabs.TabsMixin, primary.PrimaryView):
-    __select__ = implements('Order') & one_line_rset()
+    __select__ = is_instance('Order') & one_line_rset()
     tabs = [_('activity-overview'), _('activity-details'), _('activity-graph')]
     default_tab = 'activity-overview'
 
@@ -58,7 +58,7 @@ class OrderPrimaryView(tabs.TabsMixin, primary.PrimaryView):
 
 class OrderOverviewView(EntityView):
     __regid__ = 'activity-overview'
-    __select__ = implements('Order')
+    __select__ = is_instance('Order')
     title = _('activity-overview')
 
     def cell_call(self, row, col):
@@ -71,7 +71,7 @@ class OrderOverviewView(EntityView):
 class OrderDetailView(EntityView):
     __regid__ = 'activity-details'
     title = _('activity-details')
-    __select__ = implements('Order') & one_line_rset()
+    __select__ = is_instance('Order') & one_line_rset()
 
     def cell_call(self, row, col):
         entity = self.cw_rset.get_entity(row, col)
@@ -81,7 +81,7 @@ class OrderDetailView(EntityView):
 class OrderGraphView(EntityView):
     __regid__ = 'activity-graph'
     title = _('activity-graph')
-    __select__ = implements('Order')
+    __select__ = is_instance('Order')
 
     def cell_call(self, row, col):
         entity = self.cw_rset.get_entity(row, col)
@@ -93,7 +93,7 @@ class OrderGraphView(EntityView):
 
 class WorkorderPrimaryView(tabs.TabsMixin, primary.PrimaryView):
     """display workpackage's activity summary"""
-    __select__ = implements('WorkOrder') & one_line_rset()
+    __select__ = is_instance('WorkOrder') & one_line_rset()
     tabs = [_('activity-overview'), _('activity-details'), _('activity-graph')]
     default_tab = 'activity-overview'
 
@@ -115,7 +115,7 @@ class WorkorderPrimaryView(tabs.TabsMixin, primary.PrimaryView):
 
 class WorkOrderOverviewView(EntityView):
     __regid__ = 'activity-overview'
-    __select__ = implements('WorkOrder')
+    __select__ = is_instance('WorkOrder')
     title = _('activity-overview')
 
     def cell_call(self, row, col):
@@ -128,7 +128,7 @@ class WorkOrderOverviewView(EntityView):
 
 class WorkOrderDetailView(EntityView):
     __regid__ = 'activity-details'
-    __select__ = implements('WorkOrder') & one_line_rset()
+    __select__ = is_instance('WorkOrder') & one_line_rset()
     title = _('activity-details')
 
     def cell_call(self, row, col):
@@ -139,7 +139,7 @@ class WorkOrderDetailView(EntityView):
 class WorkOrderGraphView(EntityView):
     __regid__ = 'activity-graph'
     title = _('activity-graph')
-    __select__ = implements('WorkOrder')
+    __select__ = is_instance('WorkOrder')
 
     def cell_call(self, row, col):
         entity = self.cw_rset.get_entity(row, col)
@@ -151,7 +151,7 @@ class WorkOrderGraphView(EntityView):
 
 class ResourcePrimaryView(tabs.TabsMixin, primary.PrimaryView):
     """display workpackage's activity summary"""
-    __select__ = implements('Resource') & one_line_rset()
+    __select__ = is_instance('Resource') & one_line_rset()
     tabs = [_('activity-current'), _('activity-overview'), _('activity-details'),
             _('activity-graph'), _('resource-calendar'),]
     default_tab = 'activity-current'
@@ -167,7 +167,7 @@ class ResourcePrimaryView(tabs.TabsMixin, primary.PrimaryView):
 class ResourceRecentView(EntityView):
     __regid__ = 'activity-current'
     title = _('recent activities')
-    __select__ = implements('Resource')
+    __select__ = is_instance('Resource')
 
     def cell_call(self, row, col):
         entity = self.cw_rset.get_entity(row, col)
@@ -184,7 +184,7 @@ class ResourceRecentView(EntityView):
 
 class ResourceOverviewView(EntityView):
     __regid__ = 'activity-overview'
-    __select__ = implements('Resource')
+    __select__ = is_instance('Resource')
     title = _('activity overview')
 
     def cell_call(self, row, col):
@@ -197,7 +197,7 @@ class ResourceOverviewView(EntityView):
 
 class ResourceDetailView(EntityView):
     __regid__ = 'activity-details'
-    __select__ = implements('Resource') & one_line_rset()
+    __select__ = is_instance('Resource') & one_line_rset()
     title = _('activity details')
 
     def cell_call(self, row, col):
@@ -208,7 +208,7 @@ class ResourceDetailView(EntityView):
 
 class ResourceGraphView(EntityView):
     __regid__ = 'activity-graph'
-    __select__ = implements('Resource')
+    __select__ = is_instance('Resource')
     title = _('activity-graph')
 
     def cell_call(self, row, col):
@@ -219,7 +219,7 @@ class ResourceGraphView(EntityView):
 
 class ResourceCalendarView(EntityView):
     __regid__ = 'resource-calendar'
-    __select__ = implements('Resource')
+    __select__ = is_instance('Resource')
     title = _('resource-calendar')
 
     def cell_call(self, row, col):
@@ -237,13 +237,14 @@ class ResourceCalendarView(EntityView):
 # activity  ######################################################################
 
 class ActivityPrimaryView(primary.PrimaryView):
-    __select__ = implements('Activity')
+    __select__ = is_instance('Activity')
 
     def cell_call(self, row, col):
         _ = self._cw._
         activity = self.cw_rset.get_entity(row, col)
-        self.w(u'<h2>%s: %s</h2>' % (display_name(self._cw, 'State'),
-                                     xml_escape(self._cw._(activity.state))))
+        self.w(u'<h2>%s: %s</h2>' % (
+            display_name(self._cw, 'State'),
+            xml_escape(activity.cw_adapt_to('IWorkflowable').printable_state)))
         rql = ("Any D,U,DU,WO,DE,A WHERE A is Activity, A done_by R, R euser U, "
                "A diem D, A done_for WO, A eid %(x)s, A duration DU, A description DE")
         headers  = (_("diem"), _("euser"), _("duration"), _("workpackage"), _("description"), u"")
